==> AxolotlClient-3.1.6%2B1.20.1-sources.jar: io/github/axolotlclient/modules/hud/gui/keystrokes/SpecialKeystrokeSelectionList.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.modules.hud.gui.keystrokes;

import java.util.Arrays;
import java.util.List;

import com.google.common.collect.ImmutableList;
import io.github.axolotlclient.AxolotlClientConfig.api.util.Colors;
import io.github.axolotlclient.modules.hud.gui.hud.KeystrokeHud;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_364;
import net.minecraft.class_4185;
import net.minecraft.class_4265;
import net.minecraft.class_6379;
import org.apache.commons.lang3.ArrayUtils;

@Environment(EnvType.CLIENT)
public class SpecialKeystrokeSelectionList extends class_4265<SpecialKeystrokeSelectionList.Entry> {
	private static final int ITEM_HEIGHT = 20;
	final AddSpecialKeystrokeScreen keyBindsScreen;

	public SpecialKeystrokeSelectionList(AddSpecialKeystrokeScreen keyBindsScreen, class_310 minecraft) {
		super(minecraft, keyBindsScreen.field_22789, keyBindsScreen.field_22790, 33, keyBindsScreen.field_22790 - 33, ITEM_HEIGHT);
		this.keyBindsScreen = keyBindsScreen;
		KeystrokeHud.SpecialKeystroke[] strokes = ArrayUtils.clone(KeystrokeHud.SpecialKeystroke.values());
		Arrays.sort(strokes);

		for (KeystrokeHud.SpecialKeystroke keyMapping : strokes) {
			this.method_25321(new KeyEntry(keyMapping));
		}
	}

	@Override
	public int method_25322() {
		return 340;
	}

	@Override
	protected int method_25329() {
		return method_25342() + method_25322() + 10;
	}

	@Environment(EnvType.CLIENT)
	public abstract static class Entry extends class_4265.class_4266<Entry> {

	}

	@Environment(EnvType.CLIENT)
	public class KeyEntry extends Entry {
		private final class_2561 boundKey;
		private final class_4185 addButton;
		private final KeystrokeHud.Keystroke keystroke;

		KeyEntry(final KeystrokeHud.SpecialKeystroke key) {
			this.keystroke = keyBindsScreen.hud.newSpecialStroke(key);
			this.boundKey = key.getKey().getKeyName();
			this.addButton = class_4185.method_46430(class_2561.method_43471("keystrokes.stroke.add"), button -> keyBindsScreen.hud.keystrokes.add(keyBindsScreen.hud.newSpecialStroke(key)))
				.method_46434(0, 0, 75, 20)
				.method_46431();
		}

		@Override
		public void method_25343(class_332 guiGraphics, int index, int top, int left, int width, int height, int mouseX, int mouseY, boolean hovering, float partialTick) {
			int i = SpecialKeystrokeSelectionList.this.method_25329() - 10;
			int j = top - 2;
			int k = i - 5 - this.addButton.method_25368();
			this.addButton.method_48229(k, j);
			this.addButton.method_25394(guiGraphics, mouseX, mouseY, partialTick);
			guiGraphics.method_51448().method_22903();
			var rect = keystroke.getRenderPosition();
			float scale = Math.min((float) height / rect.height(), (float) 100 / rect.width());
			guiGraphics.method_51448().method_46416(left, top, 0);
			guiGraphics.method_51448().method_22905(scale, scale, 1);
			guiGraphics.method_51448().method_46416(-rect.x(), -rect.y(), 0);
			keystroke.render(guiGraphics);
			guiGraphics.method_51448().method_22909();
			guiGraphics.method_27535(field_22740.field_1772, boundKey, left + 110 + (k - left - 110) / 3, top + height / 2 - 9 / 2, Colors.GRAY.toInt());
		}

		@Override
		public List<? extends class_364> method_25396() {
			return ImmutableList.of(this.addButton);
		}

		@Override
		public List<? extends class_6379> method_37025() {
			return ImmutableList.of(this.addButton);
		}
	}
}

==> AxolotlClient-3.1.8%2B1.21.1-sources.jar: io/github/axolotlclient/modules/hud/gui/keystrokes/SpecialKeystrokeSelectionList.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.modules.hud.gui.keystrokes;

import java.util.Arrays;
import java.util.List;

import com.google.common.collect.ImmutableList;
import io.github.axolotlclient.AxolotlClientConfig.api.util.Colors;
import io.github.axolotlclient.modules.hud.gui.hud.KeystrokeHud;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_364;
import net.minecraft.class_4185;
import net.minecraft.class_4265;
import net.minecraft.class_6379;
import org.apache.commons.lang3.ArrayUtils;

@Environment(EnvType.CLIENT)
public class SpecialKeystrokeSelectionList extends class_4265<SpecialKeystrokeSelectionList.Entry> {
	private static final int ITEM_HEIGHT = 20;
	final AddSpecialKeystrokeScreen keyBindsScreen;

	public SpecialKeystrokeSelectionList(AddSpecialKeystrokeScreen keyBindsScreen, class_310 minecraft) {
		super(minecraft, keyBindsScreen.field_22789, keyBindsScreen.layout.method_57727(), keyBindsScreen.layout.method_48998(), ITEM_HEIGHT);
		this.keyBindsScreen = keyBindsScreen;
		KeystrokeHud.SpecialKeystroke[] strokes = ArrayUtils.clone(KeystrokeHud.SpecialKeystroke.values());
		Arrays.sort(strokes);

		for (KeystrokeHud.SpecialKeystroke keyMapping : strokes) {
			this.method_25321(new KeyEntry(keyMapping));
		}
	}

	@Override
	public int method_25322() {
		return 340;
	}

	@Environment(EnvType.CLIENT)
	public abstract static class Entry extends class_4265.class_4266<Entry> {

	}

	@Environment(EnvType.CLIENT)
	public class KeyEntry extends Entry {
		private final class_2561 boundKey;
		private final class_4185 addButton;
		private final KeystrokeHud.Keystroke keystroke;

		KeyEntry(final KeystrokeHud.SpecialKeystroke key) {
			this.keystroke = keyBindsScreen.hud.newSpecialStroke(key);
			this.boundKey = key.getKey().getKeyName();
			this.addButton = class_4185.method_46430(class_2561.method_43471("keystrokes.stroke.add"), button -> keyBindsScreen.hud.keystrokes.add(keyBindsScreen.hud.newSpecialStroke(key)))
				.method_46434(0, 0, 75, 20)
				.method_46431();
		}

		@Override
		public void method_25343(class_332 guiGraphics, int index, int top, int left, int width, int height, int mouseX, int mouseY, boolean hovering, float partialTick) {
			int i = SpecialKeystrokeSelectionList.this.method_25329() - 10;
			int j = top - 2;
			int k = i - 5 - this.addButton.method_25368();
			this.addButton.method_48229(k, j);
			this.addButton.method_25394(guiGraphics, mouseX, mouseY, partialTick);
			guiGraphics.method_51448().method_22903();
			var rect = keystroke.getRenderPosition();
			float scale = Math.min((float) height / rect.height(), (float) 100 / rect.width());
			guiGraphics.method_51448().method_46416(left, top, 0);
			guiGraphics.method_51448().method_22905(scale, scale, 1);
			guiGraphics.method_51448().method_46416(-rect.x(), -rect.y(), 0);
			keystroke.render(guiGraphics);
			guiGraphics.method_51448().method_22909();
			guiGraphics.method_27535(field_22740.field_1772, boundKey, left + 110 + (k - left - 110) / 3, top + height / 2 - 9 / 2, Colors.GRAY.toInt());
		}

		@Override
		public List<? extends class_364> method_25396() {
			return ImmutableList.of(this.addButton);
		}

		@Override
		public List<? extends class_6379> method_37025() {
			return ImmutableList.of(this.addButton);
		}
	}
}
